package net.mc_pandacraft.java.plugin.pandacraftutils.data_model;

import java.sql.SQLException;

/**
 * Représente un message dans la base de donnée<br/>
 * <br/>
 * Les propriétés suivantes doivent être complétés hors constructeur (par défaut <code>null</code>) :
 * <ul>
 * 	<li><code>destNick</code></li>
 * 	<li>ou <code>destGroup</code></li>
 * </ul>
 * La propriété <code>deleted</code> est défini par défaut à Faux.
 * @author Marc Baloup
 *
 */
public class MPMessageElement extends SQLElement {

	private long time;
	private int securityKey; // permet de différencier deux message, dans le cas où 2 messages ont exactement la même valeur time
	private String viewerNick;
	private String sourceNick;
	private String destNick = null;
	private Integer destGroup = null;
	private String message;
	private boolean wasRead;
	private boolean deleted = false;
	private boolean serverSync;
	

	
	public MPMessageElement(long t, int secKey, String viewNick, String srcNick, String msg, boolean r, boolean sync) {
		super("pandacraft_mp_message");
		setTime(t);
		setSecurityKey(secKey);
		setViewerNick(viewNick);
		setSourceNick(srcNick);
		setMessage(msg);
		setRead(r);
		setServerSync(sync);
	}
	
	
	protected MPMessageElement(int id, long t, int secKey, String viewNick, String srcNick, String msg, boolean r, boolean sync) {
		super("pandacraft_mp_message", id);
		setTime(t);
		setSecurityKey(secKey);
		setViewerNick(viewNick);
		setSourceNick(srcNick);
		setMessage(msg);
		setRead(r);
		setServerSync(sync);
	}

	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	@Override
	protected String[] getValues() {
		return new String[] {
				Long.toString(time),
				Integer.toString(securityKey),
				viewerNick,
				sourceNick,
				destNick,
				(destGroup==null)?null:destGroup.toString(),
				message,
				(wasRead)?"1":"0",
				(deleted)?"1":"0",
				(serverSync)?"1":"0"
		};
	}

	
	
	
	@Override
	protected String[] getFieldsName() {
		return new String[] {
				"time",
				"securityKey",
				"viewerNick",
				"sourceNick",
				"destNick",
				"destGroup",
				"message",
				"wasRead",
				"deleted",
				"serverSync"
		};
	}


	public long getTime() { return time; }
	public int getSecurityKey() { return securityKey; }
	public String getViewerNick() { return viewerNick; }
	public String getSourceNick() { return sourceNick; }
	public String getDestNick() { return destNick; }
	public Integer getDestGroup() { return destGroup; }
	public String getMessage() { return message; }
	public boolean isRead() { return wasRead; }
	public boolean isDeleted() { return deleted; }
	public boolean isServerSync() { return serverSync; }
	
	
	
	
	public void setTime(long t) { time = t; }
	public void setSecurityKey(int secKey) { securityKey = secKey; }
	
	public void setViewerNick(String viewNick) {
		if (viewNick == null)
			throw new NullPointerException();
		viewerNick = viewNick;
	}

	public void setSourceNick(String srcNick) { sourceNick = srcNick; }

	public void setDestNick(String destNick) {
		this.destNick = destNick;
		if (destNick != null)
			destGroup = null;
	}

	public void setDestGroup(Integer destGroup) {
		this.destGroup = destGroup;
		if (destGroup != null)
			destNick = null;
	}

	public void setMessage(String msg) {
		if (msg == null)
			throw new NullPointerException();
		message = msg;
	}

	public void setRead(boolean r) { wasRead = r; }
	public void setDeleted(boolean del) { deleted = del; }
	public void setServerSync(boolean sync) { serverSync = sync; }
	
	
	
	
	
	public MPGroupElement getDestGroupElement() throws SQLException {
		if (getDestGroup() == null) return null;
		
		return ORM.getTable(MPGroupTable.class).get(getDestGroup());
	}

}
